Documentation
¶
Overview ¶
Package snapcraft implements the Pipe interface providing Snapcraft bindings.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoDescription = errors.New("no description provided for snapcraft")
ErrNoDescription is shown when no description provided
var ErrNoSnapcraft = errors.New("snapcraft not present in $PATH")
ErrNoSnapcraft is shown when snapcraft cannot be found in $PATH
var ErrNoSummary = errors.New("no summary provided for snapcraft")
ErrNoSummary is shown when no summary provided
Functions ¶
This section is empty.
Types ¶
type AppMetadata ¶ added in v0.28.3
type AppMetadata struct {
Command string
Plugs []string `yaml:",omitempty"`
Daemon string `yaml:",omitempty"`
}
AppMetadata for the binaries that will be in the snap package
type Metadata ¶ added in v0.32.0
type Metadata struct {
Name string
Version string
Summary string
Description string
Grade string `yaml:",omitempty"`
Confinement string `yaml:",omitempty"`
Architectures []string
Apps map[string]AppMetadata
}
Metadata to generate the snap package
Click to show internal directories.
Click to hide internal directories.